@@ -10,8 +10,7 @@
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU Affero General Public License as        *
- *   published by the Free Software Foundation, either version 3 of the    *
- *   License, or (at your option) any later version.                       *
+ *   published by the Free Software Foundation, version 3 of the License.  *
  *                                                                         *
  ***************************************************************************/
 
@@ -27,11 +26,9 @@
 
 #include <QMessageBox>
 
-/*
 #include <Qt>
 #include <QShortcut>
 #include <QKeySequence>
-*/
 
 #include <QListWidget>
 #include <QScrollBar>
@@ -88,47 +85,54 @@ SubgroupsForm::SubgroupsForm(QWidget* parent): QDialog(parent)
 	connect(codePushButton, &QPushButton::clicked, this, &SubgroupsForm::code);
 	connect(commentsPushButton, &QPushButton::clicked, this, &SubgroupsForm::comments);
 
-	/*
-	QShortcut* addShortcut=new QShortcut(QKeySequence(Qt::Key_Plus), this);
-	connect(addShortcut, &QShortcut::activated, [=]{addSubgroupPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		addSubgroupPushButton->setToolTip(QString("+"));
-	//
-	QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
-	connect(modifyShortcut, &QShortcut::activated, [=]{modifySubgroupPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		modifySubgroupPushButton->setToolTip(QString("M"));
-	//
-	QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
-	connect(removeShortcut, &QShortcut::activated, [=]{removeSubgroupPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		removeSubgroupPushButton->setToolTip(QString("⌦"));
-	//
-	QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
-	connect(activateShortcut, &QShortcut::activated, [=]{activateStudentsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		activateStudentsPushButton->setToolTip(QString("A"));
-	//
-	QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
-	connect(deactivateShortcut, &QShortcut::activated, [=]{deactivateStudentsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		deactivateStudentsPushButton->setToolTip(QString("D"));
-	//
-	QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
-	connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		commentsPushButton->setToolTip(QString("C"));
-	//
-	QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
-	connect(upShortcut, &QShortcut::activated, [=]{moveSubgroupUpPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveSubgroupUpPushButton->setToolTip(QString("U"));
-	//
-	QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
-	connect(downShortcut, &QShortcut::activated, [=]{moveSubgroupDownPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveSubgroupDownPushButton->setToolTip(QString("J"));
-	*/
+	if(SHORTCUT_PLUS){
+		QShortcut* addShortcut=new QShortcut(QKeySequence(Qt::Key_Plus), this);
+		connect(addShortcut, &QShortcut::activated, [=]{addSubgroupPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	addSubgroupPushButton->setToolTip(QString("+"));
+	}
+	if(SHORTCUT_M){
+		QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
+		connect(modifyShortcut, &QShortcut::activated, [=]{modifySubgroupPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	modifySubgroupPushButton->setToolTip(QString("M"));
+	}
+	if(SHORTCUT_DELETE){
+		QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
+		connect(removeShortcut, &QShortcut::activated, [=]{removeSubgroupPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	removeSubgroupPushButton->setToolTip(QString("⌦"));
+	}
+	if(SHORTCUT_A){
+		QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
+		connect(activateShortcut, &QShortcut::activated, [=]{activateStudentsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	activateStudentsPushButton->setToolTip(QString("A"));
+	}
+	if(SHORTCUT_D){
+		QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
+		connect(deactivateShortcut, &QShortcut::activated, [=]{deactivateStudentsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	deactivateStudentsPushButton->setToolTip(QString("D"));
+	}
+	if(SHORTCUT_C){
+		QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
+		connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	commentsPushButton->setToolTip(QString("C"));
+	}
+	if(SHORTCUT_U){
+		QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
+		connect(upShortcut, &QShortcut::activated, [=]{moveSubgroupUpPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveSubgroupUpPushButton->setToolTip(QString("U"));
+	}
+	if(SHORTCUT_J){
+		QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
+		connect(downShortcut, &QShortcut::activated, [=]{moveSubgroupDownPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveSubgroupDownPushButton->setToolTip(QString("J"));
+	}
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
